@@ -1,10 +1,14 @@
 from types import ModuleType
 from importlib import import_module
 
+from .seed import seed_everything
 from .debug import is_debug_enabled, debug, set_debug
+
 import torch_geometric.data
+import torch_geometric.loader
 import torch_geometric.transforms
 import torch_geometric.utils
+import torch_geometric.profile
 
 
 # https://github.com/tensorflow/tensorflow/blob/master/tensorflow/
@@ -32,10 +36,12 @@ class LazyLoader(ModuleType):
 
 datasets = LazyLoader('datasets', globals(), 'torch_geometric.datasets')
 nn = LazyLoader('nn', globals(), 'torch_geometric.nn')
+graphgym = LazyLoader('graphgym', globals(), 'torch_geometric.graphgym')
 
-__version__ = '1.7.2'
+__version__ = '2.0.0'
 
 __all__ = [
+    'seed_everything',
     'is_debug_enabled',
     'debug',
     'set_debug',
