@@ -1,5 +1,4 @@
-from __future__ import print_function
-
+import sys
 import os.path as osp
 import tarfile
 import zipfile
@@ -9,10 +8,10 @@ import gzip
 
 def maybe_log(path, log=True):
     if log:
-        print('Extracting', path)
+        print(f'Extracting {path}', file=sys.stderr)
 
 
-def extract_tar(path, folder, mode='r:gz', log=True):
+def extract_tar(path: str, folder: str, mode: str = 'r:gz', log: bool = True):
     r"""Extracts a tar archive to a specific folder.
 
     Args:
@@ -27,7 +26,7 @@ def extract_tar(path, folder, mode='r:gz', log=True):
         f.extractall(folder)
 
 
-def extract_zip(path, folder, log=True):
+def extract_zip(path: str, folder: str, log: bool = True):
     r"""Extracts a zip archive to a specific folder.
 
     Args:
@@ -41,7 +40,15 @@ def extract_zip(path, folder, log=True):
         f.extractall(folder)
 
 
-def extract_bz2(path, folder, log=True):
+def extract_bz2(path: str, folder: str, log: bool = True):
+    r"""Extracts a bz2 archive to a specific folder.
+
+    Args:
+        path (string): The path to the tar archive.
+        folder (string): The folder.
+        log (bool, optional): If :obj:`False`, will not print anything to the
+            console. (default: :obj:`True`)
+    """
     maybe_log(path, log)
     path = osp.abspath(path)
     with bz2.open(path, 'r') as r:
@@ -49,7 +56,15 @@ def extract_bz2(path, folder, log=True):
             w.write(r.read())
 
 
-def extract_gz(path, folder, log=True):
+def extract_gz(path: str, folder: str, log: bool = True):
+    r"""Extracts a gz archive to a specific folder.
+
+    Args:
+        path (string): The path to the tar archive.
+        folder (string): The folder.
+        log (bool, optional): If :obj:`False`, will not print anything to the
+            console. (default: :obj:`True`)
+    """
     maybe_log(path, log)
     path = osp.abspath(path)
     with gzip.open(path, 'r') as r:
