@@ -14,9 +14,11 @@ from .yelp import Yelp
 from .amazon_products import AmazonProducts
 from .qm7 import QM7b
 from .qm9 import QM9
+from .md17 import MD17
 from .zinc import ZINC
 from .molecule_net import MoleculeNet
 from .entities import Entities
+from .rel_link_pred_dataset import RelLinkPredDataset
 from .ged_dataset import GEDDataset
 from .mnist_superpixels import MNISTSuperpixels
 from .faust import FAUST
@@ -45,6 +47,10 @@ from .wikics import WikiCS
 from .webkb import WebKB
 from .wikipedia_network import WikipediaNetwork
 from .actor import Actor
+from .ogb_mag import OGB_MAG
+from .dblp import DBLP
+from .imdb import IMDB
+from .last_fm import LastFM
 from .jodie import JODIEDataset
 from .mixhop_synthetic_dataset import MixHopSyntheticDataset
 from .upfd import UPFD
@@ -73,9 +79,11 @@ __all__ = [
     'AmazonProducts',
     'QM7b',
     'QM9',
+    'MD17',
     'ZINC',
     'MoleculeNet',
     'Entities',
+    'RelLinkPredDataset',
     'GEDDataset',
     'MNISTSuperpixels',
     'FAUST',
@@ -105,6 +113,10 @@ __all__ = [
     'WebKB',
     'WikipediaNetwork',
     'Actor',
+    'OGB_MAG',
+    'DBLP',
+    'IMDB',
+    'LastFM',
     'JODIEDataset',
     'MixHopSyntheticDataset',
     'UPFD',
