@@ -4,10 +4,8 @@ import os
 import os.path as osp
 from collections import Counter
 
-import gzip
-import pandas as pd
-import numpy as np
 import torch
+import numpy as np
 
 from torch_geometric.data import (InMemoryDataset, Data, download_url,
                                   extract_tar)
@@ -52,11 +50,11 @@ class Entities(InMemoryDataset):
         return osp.join(self.root, self.name, 'processed')
 
     @property
-    def num_relations(self) -> str:
+    def num_relations(self) -> int:
         return self.data.edge_type.max().item() + 1
 
     @property
-    def num_classes(self) -> str:
+    def num_classes(self) -> int:
         return self.data.train_y.max().item() + 1
 
     @property
@@ -78,6 +76,8 @@ class Entities(InMemoryDataset):
         os.unlink(path)
 
     def process(self):
+        import gzip
+        import pandas as pd
         import rdflib as rdf
 
         graph_file, task_file, train_file, test_file = self.raw_paths
