@@ -2,7 +2,7 @@ import os
 
 import torch
 from torch_geometric.data import (InMemoryDataset, Data, download_url,
-                                  extract_tar)
+                                  extract_zip)
 
 
 class MNISTSuperpixels(InMemoryDataset):
@@ -30,8 +30,7 @@ class MNISTSuperpixels(InMemoryDataset):
             final dataset. (default: :obj:`None`)
     """
 
-    url = ('https://graphics.cs.tu-dortmund.de/fileadmin/ls7-www/misc/cvpr/'
-           'mnist_superpixels.tar.gz')
+    url = 'https://data.pyg.org/datasets/MNISTSuperpixels.zip'
 
     def __init__(self, root, train=True, transform=None, pre_transform=None,
                  pre_filter=None):
@@ -42,41 +41,26 @@ class MNISTSuperpixels(InMemoryDataset):
 
     @property
     def raw_file_names(self):
-        return ['training.pt', 'test.pt']
+        return ['MNISTSuperpixels.pt']
 
     @property
     def processed_file_names(self):
-        return ['training.pt', 'test.pt']
+        return ['train_data.pt', 'test_data.pt']
 
     def download(self):
         path = download_url(self.url, self.raw_dir)
-        extract_tar(path, self.raw_dir, mode='r')
+        extract_zip(path, self.raw_dir)
         os.unlink(path)
 
     def process(self):
-        for raw_path, path in zip(self.raw_paths, self.processed_paths):
-            x, edge_index, edge_slice, pos, y = torch.load(raw_path)
-            edge_index, y = edge_index.to(torch.long), y.to(torch.long)
-            m, n = y.size(0), 75
-            x, pos = x.view(m * n, 1), pos.view(m * n, 2)
-            node_slice = torch.arange(0, (m + 1) * n, step=n, dtype=torch.long)
-            graph_slice = torch.arange(m + 1, dtype=torch.long)
-            self.data = Data(x=x, edge_index=edge_index, y=y, pos=pos)
-            self.slices = {
-                'x': node_slice,
-                'edge_index': edge_slice,
-                'y': graph_slice,
-                'pos': node_slice
-            }
+        inputs = torch.load(self.raw_paths[0])
+        for i in range(len(inputs)):
+            data_list = [Data(**data_dict) for data_dict in inputs[i]]
 
             if self.pre_filter is not None:
-                data_list = [self.get(idx) for idx in range(len(self))]
                 data_list = [d for d in data_list if self.pre_filter(d)]
-                self.data, self.slices = self.collate(data_list)
 
             if self.pre_transform is not None:
-                data_list = [self.get(idx) for idx in range(len(self))]
-                data_list = [self.pre_transform(data) for data in data_list]
-                self.data, self.slices = self.collate(data_list)
+                data_list = [self.pre_transform(d) for d in data_list]
 
-            torch.save((self.data, self.slices), path)
+            torch.save(self.collate(data_list), self.processed_paths[i])
