@@ -2,10 +2,10 @@ from typing import Union, Tuple
 from torch_geometric.typing import OptPairTensor, Adj, Size
 
 from torch import Tensor
-from torch.nn import Linear
 import torch.nn.functional as F
 from torch_sparse import SparseTensor, matmul
 from torch_geometric.nn.conv import MessagePassing
+from torch_geometric.nn.dense.linear import Linear
 
 
 class SAGEConv(MessagePassing):
@@ -17,8 +17,10 @@ class SAGEConv(MessagePassing):
         \mathrm{mean}_{j \in \mathcal{N(i)}} \mathbf{x}_j
 
     Args:
-        in_channels (int or tuple): Size of each input sample. A tuple
-            corresponds to the sizes of source and target dimensionalities.
+        in_channels (int or tuple): Size of each input sample, or :obj:`-1` to
+            derive the size from the first input(s) to the forward method.
+            A tuple corresponds to the sizes of source and target
+            dimensionalities.
         out_channels (int): Size of each output sample.
         normalize (bool, optional): If set to :obj:`True`, output features
             will be :math:`\ell_2`-normalized, *i.e.*,
