@@ -1,12 +1,14 @@
 import sys
 import os.path as osp
-from tempfile import NamedTemporaryFile as TempFile
-from importlib.util import spec_from_file_location, module_from_spec
+from getpass import getuser
+from tempfile import NamedTemporaryFile as TempFile, gettempdir
+from importlib.util import module_from_spec, spec_from_file_location
+
 from torch_geometric.data.makedirs import makedirs
 
 
 def class_from_module_repr(cls_name, module_repr):
-    path = osp.join('/tmp', 'pyg_jit')
+    path = osp.join(gettempdir(), f'{getuser()}_pyg')
     makedirs(path)
     with TempFile(mode='w+', suffix='.py', delete=False, dir=path) as f:
         f.write(module_repr)
