@@ -1,3 +1,4 @@
+from .linear import Linear
 from .dense_sage_conv import DenseSAGEConv
 from .dense_gcn_conv import DenseGCNConv
 from .dense_graph_conv import DenseGraphConv
@@ -6,6 +7,7 @@ from .diff_pool import dense_diff_pool
 from .mincut_pool import dense_mincut_pool
 
 __all__ = [
+    'Linear',
     'DenseGCNConv',
     'DenseGINConv',
     'DenseGraphConv',
