@@ -5,6 +5,14 @@ from torch.nn import Linear
 
 class DenseSAGEConv(torch.nn.Module):
     r"""See :class:`torch_geometric.nn.conv.SAGEConv`.
+
+    .. note::
+
+        :class:`~torch_geometric.nn.dense.DenseSAGEConv` expects to work on
+        binary adjacency matrices.
+        If you want to make use of weighted dense adjacency matrices, please
+        use :class:`torch_geometric.nn.dense.DenseGraphConv` instead.
+
     """
     def __init__(self, in_channels, out_channels, normalize=False, bias=True):
         super(DenseSAGEConv, self).__init__()
