@@ -39,6 +39,17 @@ class ASAPooling(torch.nn.Module):
             loops to the new graph connectivity. (default: :obj:`False`)
         **kwargs (optional): Additional parameters for initializing the
             graph neural network layer.
+
+    Returns:
+        A tuple of tensors containing
+
+            - **x** (*Tensor*): The pooled node embeddings.
+            - **edge_index** (*Tensor*): The coarsened graph connectivity.
+            - **edge_weight** (*Tensor*): The edge weights corresponding to the
+              coarsened graph connectivity.
+            - **batch** (*Tensor*): The pooled :obj:`batch` vector.
+            - **perm** (*Tensor*): The top-:math:`k` node indices of nodes
+              which are kept after pooling.
     """
     def __init__(self, in_channels: int, ratio: Union[float, int] = 0.5,
                  GNN: Optional[Callable] = None, dropout: float = 0.0,
@@ -69,6 +80,7 @@ class ASAPooling(torch.nn.Module):
             self.gnn_intra_cluster.reset_parameters()
 
     def forward(self, x, edge_index, edge_weight=None, batch=None):
+        """"""
         N = x.size(0)
 
         edge_index, edge_weight = add_remaining_self_loops(
