@@ -1,7 +1,9 @@
 from typing import List, Callable
 
+from torch_geometric.transforms import BaseTransform
 
-class Compose(object):
+
+class Compose(BaseTransform):
     """Composes several transforms together.
 
     Args:
@@ -12,7 +14,10 @@ class Compose(object):
 
     def __call__(self, data):
         for transform in self.transforms:
-            data = transform(data)
+            if isinstance(data, (list, tuple)):
+                data = [transform(d) for d in data]
+            else:
+                data = transform(data)
         return data
 
     def __repr__(self):
