@@ -3,10 +3,12 @@ import re
 import torch
 import torch.nn.functional as F
 from torch_scatter import scatter_add, scatter_mean
+
 import torch_geometric
+from torch_geometric.transforms import BaseTransform
 
 
-class GridSampling(object):
+class GridSampling(BaseTransform):
     r"""Clusters points into voxels with size :attr:`size`.
 
     Args:
