@@ -1,15 +1,16 @@
 import torch
 
+from torch_geometric.transforms import BaseTransform
 
-class LinearTransformation(object):
+
+class LinearTransformation(BaseTransform):
     r"""Transforms node positions with a square transformation matrix computed
     offline.
 
     Args:
-        matrix (Tensor): tensor with shape :math:`[D, D]` where :math:`D`
+        matrix (Tensor): tensor with shape :obj:`[D, D]` where :obj:`D`
             corresponds to the dimensionality of node positions.
     """
-
     def __init__(self, matrix):
         assert matrix.dim() == 2, (
             'Transformation matrix should be two-dimensional.')
@@ -17,7 +18,9 @@ class LinearTransformation(object):
             'Transformation matrix should be square. Got [{} x {}] rectangular'
             'matrix.'.format(*matrix.size()))
 
-        self.matrix = matrix
+        # Store the matrix as its transpose.
+        # We do this to enable post-multiplication in `__call__`.
+        self.matrix = matrix.t()
 
     def __call__(self, data):
         pos = data.pos.view(-1, 1) if data.pos.dim() == 1 else data.pos
@@ -26,6 +29,9 @@ class LinearTransformation(object):
             'Node position matrix and transformation matrix have incompatible '
             'shape.')
 
+        # We post-multiply the points by the transformation matrix instead of
+        # pre-multiplying, because `data.pos` has shape `[N, D]`, and we want
+        # to preserve this shape.
         data.pos = torch.matmul(pos, self.matrix.to(pos.dtype).to(pos.device))
 
         return data
