@@ -1,9 +1,11 @@
 import torch
 import torch.nn.functional as F
+
 from torch_geometric.utils import degree
+from torch_geometric.transforms import BaseTransform
 
 
-class OneHotDegree(object):
+class OneHotDegree(BaseTransform):
     r"""Adds the node degree as one hot encodings to the node features.
 
     Args:
@@ -14,7 +16,6 @@ class OneHotDegree(object):
         cat (bool, optional): Concat node degrees to node features instead
             of replacing them. (default: :obj:`True`)
     """
-
     def __init__(self, max_degree, in_degree=False, cat=True):
         self.max_degree = max_degree
         self.in_degree = in_degree
