@@ -1,8 +1,10 @@
 import torch
+
 import torch_geometric
+from torch_geometric.transforms import BaseTransform
 
 
-class PointPairFeatures(object):
+class PointPairFeatures(BaseTransform):
     r"""Computes the rotation-invariant Point Pair Features
 
     .. math::
