@@ -8,8 +8,9 @@ from .num_nodes import maybe_num_nodes
 
 
 @torch.jit.script
-def softmax(src: Tensor, index: Optional[Tensor], ptr: Optional[Tensor] = None,
-            num_nodes: Optional[int] = None) -> Tensor:
+def softmax(src: Tensor, index: Optional[Tensor] = None,
+            ptr: Optional[Tensor] = None, num_nodes: Optional[int] = None,
+            dim: int = 0) -> Tensor:
     r"""Computes a sparsely evaluated softmax.
     Given a value tensor :attr:`src`, this function first groups the values
     along the first dimension based on the indices specified in :attr:`index`,
@@ -17,22 +18,31 @@ def softmax(src: Tensor, index: Optional[Tensor], ptr: Optional[Tensor] = None,
 
     Args:
         src (Tensor): The source tensor.
-        index (LongTensor): The indices of elements for applying the softmax.
+        index (LongTensor, optional): The indices of elements for applying the
+            softmax. (default: :obj:`None`)
         ptr (LongTensor, optional): If given, computes the softmax based on
             sorted inputs in CSR representation. (default: :obj:`None`)
         num_nodes (int, optional): The number of nodes, *i.e.*
             :obj:`max_val + 1` of :attr:`index`. (default: :obj:`None`)
+        dim (int, optional): The dimension in which to normalize.
+            (default: :obj:`0`)
 
     :rtype: :class:`Tensor`
     """
-    out = src - src.max()
-    out = out.exp()
-
     if ptr is not None:
+        dim = dim + src.dim() if dim < 0 else dim
+        size = ([1] * dim) + [-1]
+        ptr = ptr.view(size)
+        src_max = gather_csr(segment_csr(src, ptr, reduce='max'), ptr)
+        out = (src - src_max).exp()
         out_sum = gather_csr(segment_csr(out, ptr, reduce='sum'), ptr)
     elif index is not None:
         N = maybe_num_nodes(index, num_nodes)
-        out_sum = scatter(out, index, dim=0, dim_size=N, reduce='sum')[index]
+        src_max = scatter(src, index, dim, dim_size=N, reduce='max')
+        src_max = src_max.index_select(dim, index)
+        out = (src - src_max).exp()
+        out_sum = scatter(out, index, dim, dim_size=N, reduce='sum')
+        out_sum = out_sum.index_select(dim, index)
     else:
         raise NotImplementedError
 
