@@ -6,11 +6,6 @@ from scipy.sparse.csgraph import minimum_spanning_tree
 
 from torch_geometric.utils import to_undirected
 
-try:
-    import rdkit.Chem as Chem
-except ImportError:
-    Chem = None
-
 
 def tree_decomposition(mol, return_vocab=False):
     r"""The tree decomposition algorithm of molecules from the
@@ -28,9 +23,7 @@ def tree_decomposition(mol, return_vocab=False):
 
     :rtype: (LongTensor, LongTensor, int)
     """
-
-    if Chem is None:
-        raise ImportError('Package `rdkit` could not be found.')
+    import rdkit.Chem as Chem
 
     # Cliques = rings and bonds.
     cliques = [list(x) for x in Chem.GetSymmSSSR(mol)]
